@@ -1,5 +1,3 @@
-# $Id: Message.pm,v 1.12 2002/12/10 01:47:26 btrott Exp $
-
 package Crypt::OpenPGP::Message;
 use strict;
 
@@ -89,7 +87,8 @@ Crypt::OpenPGP::Message - Sequence of PGP packets
 
     use Crypt::OpenPGP::Message;
 
-    my $msg = Crypt::OpenPGP::Message->new( Data => $packets );
+    my $data; $data .= $_ while <STDIN>;
+    my $msg = Crypt::OpenPGP::Message->new( Data => $data );
     my @pieces = $msg->pieces;
 
 =head1 DESCRIPTION
